@@ -27,13 +27,18 @@ impl From<&str> for TokenStream {
 }
 
 impl TokenStream {
-    /// Create a new `TokenStream`
     pub fn new() -> Self {
         Self {
             inner: String::new(),
         }
     }
 
+    pub fn with_capacity() -> Self {
+        Self {
+            inner: String::with_capacity(1000),
+        }
+    }
+
     /// Appends another stream to the stream
     ///
     /// note: a space will be inserted before the other stream
